@@ -7,7 +7,7 @@
 #' @param stock a stock name, e.g. cod-347d, or cod to find all cod stocks, or
 #'        NULL to process all stocks.
 #' @param year the assessment year, e.g. 2015, or 0 to process all years.
-#' @param data the data of interest, either "summary" or "refpts".
+#' @param data the data of interest, either "summary", "refpts" or "source".
 #' @param combine whether to combine the list output to a data frame.
 #' @param purpose the purpose of the entry, options are "Advice", "Bench",
 #'                "InitAdvice", default is "Advice".
@@ -36,15 +36,17 @@
 #'
 #' cod_summary <- getSAG("cod", 2015)
 #' cod_refpts <- getSAG("cod", 2015:2016, "refpts")
+#' cod_data <- getSAG("cod", 2017, "source-data")
 #' }
 #' @export
 
 getSAG <- function(stock, year, data = "summary", combine = TRUE, purpose = "Advice") {
   # select web service operation and parser
-  data <- match.arg(data, c("summary", "refpts"))
+  data <- match.arg(data, c("summary", "refpts", "source-data"))
   service <- switch(data,
                     summary = "getSummaryTable",
-                    refpts = "getFishStockReferencePoints")
+                    refpts = "getFishStockReferencePoints",
+                    `source-data` = "getStockDownloadData")
 
   # find lookup key
   assessmentKey <- findAssessmentKey(stock, year, regex = TRUE, full = FALSE)
